/*
   Copyright © 2007-2023 X2Go Project - https://wiki.x2go.org
   Copyright © 2007-2023 Oleksandr Shneyder <o.schneyder@phoca-gmbh.de>
   Copyright © 2007-2023 Heinz-M. Graesing <heinz-m.graesing@obviously-nice.de>
   Copyright © 2011-2015 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "plasmoidhovereditem.h"

#include <QDebug>

#include <plasma/widgets/frame.h>
#include <plasma/widgets/iconwidget.h>
#include <plasma/widgets/label.h>
#include <QGraphicsLinearLayout>

PlasmoidHoveredItem::PlasmoidHoveredItem(QGraphicsWidget* parent): Plasma::Frame(parent),label(0),icon(0)
{
	setAcceptHoverEvents(true);
	setZValue(0);
	layout=new QGraphicsLinearLayout(Qt::Horizontal,this);
	icon=new Plasma::IconWidget(this);
	label=new Plasma::Label(this);
	layout->addItem(icon);
	layout->addItem(label);
	layout->addStretch();
	icon->setAcceptHoverEvents(false);
	icon->setAcceptedMouseButtons(0);    
	icon->setMaximumWidth(18);
}

PlasmoidHoveredItem::~PlasmoidHoveredItem()
{
}

void PlasmoidHoveredItem::buttonPressed()
{
	emit clicked();
}

void PlasmoidHoveredItem::hoverEnter()
{
	setFrameShadow(Plasma::Frame::Raised);
	update();
}

void PlasmoidHoveredItem::hoverLeave()
{
	setFrameShadow(Plasma::Frame::Plain);
	update();
}

void PlasmoidHoveredItem::setIcon(QString icon)
{
	this->icon->setIcon(icon);
}

void PlasmoidHoveredItem::setText(QString text)
{
	label->setText(text);
}

QString PlasmoidHoveredItem::text()
{
	return label->text();
}

